#!/bin/bash

# PKGHOME: http://www.darcs.net
# AUTHOR: fdeak <ferenc.deak@gmail.com>
# NOTES: 1. You need an installed ghc (haskell compiler) to compile darcs!
# NOTES: 2. You can get ghc from www.haskell.org/ghc.
# NOTES:    We use the prebuilt documentation of the source package, so we
# NOTES:    do not need tex. Expect a little bit different build process if
# NOTES:    you have tex. But the resuting package should be the same.
# NOTES: 3. The cgi interface is included in the package, altough I've never used it.
# NOTES: 4. One test fails in the 'make test' phase, but as I see in the test code,
# NOTES:    It is not a darcs problem...
# DEPENDS: curl gmp libidn ncurses openssl perl readline zlib

soft='darcs'
softversion='1.0.8'
packageversion='44.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"
numjobs='-j2'

set -e
cd $buildir
rm -rf $src
tar xzf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest
chown -R root:root .

cd $src
find . -perm 664 -exec chmod 644 {} \;

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

# Build & install the pkg
./configure --prefix=/usr --sysconfdir=/etc --with-sendmail=sendmail
make $numjobs
make test
make DESTDIR=$dest install
make DESTDIR=$dest installserver
# we install the docs by hand
rm -rf $dest/usr/share/darcs/doc
# Zenwalk has no bash_completion by default:
rm -rf $dest/etc/bash_completion.d

# Strip binaries and libraries
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress man pages
( cd $dest/usr/man
  find . -type f -exec gzip -9 {} \;
  for i in `find . -type l` ; do ln -s $( readlink $i ).gz $i.gz ; rm $i ; done
)

# Install docs
mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS COPYING RELEASE_STATE manual/*.html manual/*.png \
  $dest/usr/doc/$soft-$softversion

# Save the build script
mkdir -p $dest/usr/src/$soft-$softversion
( cd $buildir; cp -a build-$soft.sh $dest/usr/src/$soft-$softversion/ )

# Create the /install directory
mkdir -p $dest/install
cat > $dest/install/slack-desc << END
     |-----handy-ruler------------------------------------------------------|
darcs: darcs - an advanced revision control system
darcs: 
darcs: Distributed: Every user has access to the full command set, removing
darcs: boundaries between server and client or committer and non-committers.
darcs: Interactive: Darcs is easy to learn and efficient to use because it
darcs: asks you questions in response to simple commands, giving you choices
darcs: in your work flow. You can choose to record one change in a file,
darcs: while ignoring another. As you update from upstream, you can review
darcs: each patch name, even the full "diff" for interesting patches.
darcs: Smart: Originally developed by physicist David Roundy, darcs is based
darcs: on a unique algebra of patches.
END

# Create the slackware package
cd $dest
/sbin/makepkg -l y -c n $dest.tgz
(cd $buildir; md5sum $package.tgz > $package.md5)

